# Radheef
Python library for getting the meaning of a dhivehi word and other related information

## installation
```
pip install radheef
```

## Usage example
```py
from radheef import radheef 
print(radheef("ބަރު"))
```
returns
```
ނ. 1 ލުއިގެ އިދިކޮޅު. 2 ވަޒަނުން އިތުރު. 3 ބައެއް ގަޑި ހިނގާއިރު އެލިފައި ހުރެގެން ދެފަރާތަށް ހެލިހެލި ހުންނަ އެތި. 4 ކަރުދާސް ވަޔާ ހިނގައިދާނެތީ އޭގެ މަތީ ބަހައްޓާން ގެންގުޅޭ ތަކެތި. 5 ސަންޑޯކުރާ ބަރު އުފުލަން ގެންގުޅޭ އެކި ވަރުގެ އާލާތް. 6 ނއ. މަސައްކަތް ބޮޑު.
```